<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:param name="component">all</xsl:param>
<xsl:param name="xmlFile"></xsl:param>
<xsl:param name="mDescFile"></xsl:param>

<xsl:template match="/">
  <xsl:apply-templates select="CA_CONFIG"/>
</xsl:template>

<xsl:template match="CA_CONFIG">
  <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <table border="5" width="95%" style="font-size:8pt" bordercolor="#8080cc" 
           bordercolorlight="#8080c0" bordercolordark="#400080" bgcolor="#ffffcc">
      <thead bgColor='lightgreen'>
        <th width="30%"><b>Type</b></th>
        <th><b>Description</b></th>
      </thead>
      <xsl:choose>
      <xsl:when test="$component='all'">
        <xsl:apply-templates select="TYPE">
         <xsl:sort select="@name"/>
        </xsl:apply-templates>
      </xsl:when>
      <xsl:when test="$component='delta'">
        <xsl:apply-templates select="TYPE[@status!='']">
         <xsl:sort select="@name"/>
        </xsl:apply-templates>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="TYPE[@name=$component]"/>
      </xsl:otherwise>
      </xsl:choose>
    </table>
  </div>
</xsl:template>

<xsl:template match="TYPE">
  <tr bgColor='lightyellow'>
    <td>
      <xsl:if test="not(@status!='')">	
		<xsl:value-of select="@name"/>
      </xsl:if>
      <xsl:if test="@status!=''">   
        <font color='red'><xsl:value-of select="@name"/></font>
      </xsl:if>
    </td>
    <td>
      <table border="0" width="100%" style="font-size:8pt">
        <xsl:call-template name="status"/>
        <xsl:call-template name="description"/>
        <xsl:apply-templates select="STRING|INTEGER|DIGITS|BOOLEAN|ENUM"/>
        <xsl:apply-templates select="DEFAULT_VALUE"/>
        <xsl:apply-templates select="FOREIGN_KEY"/>
      </table>
    </td>
  </tr>
</xsl:template>

<xsl:template name="description">
  <xsl:variable name="doc" select="document($mDescFile)"/>
  <xsl:variable name="desc" select="$doc/CA_CONFIG/TYPE[@name=current()/@name]/DESCRIPTION"/>
  <xsl:variable name="caution" select="$doc/CA_CONFIG/TYPE[@name=current()/@name]/CAUTION"/>
  <xsl:if test="$desc!=''">
    <tr>
      <td width="150"><b>Description: </b></td>
      <td>
        <xsl:call-template name="break">
          <xsl:with-param name="text" select="$desc/text()"/>
        </xsl:call-template>
      </td>
    </tr>
  </xsl:if>
<xsl:if test="$caution!=''">
	    <tr>
		<font color="red">
      	<td width="150"><b>CAUTION: </b></td>
		<td>
        	<xsl:call-template name="break">
          	<xsl:with-param name="text" select="$caution/text()"/>
        	</xsl:call-template>
      	</td>
		</font>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="status">
  <xsl:if test="@status!=''">
    <tr>
      <td width="150"><font color="red"><b>Status: </b></font></td>
      <td><font color="red"><b>
        This Config is <xsl:value-of select="@status"/>.
      </b></font></td>
    </tr>
  </xsl:if>
</xsl:template>  
     
<xsl:template match="STRING|ENUM">
  <tr>
    <xsl:if test="not(@status!='')">
      <td width="150"><b>Data Type: </b></td>
    </xsl:if>
    <xsl:if test="@status!=''">
      <td width="150">
        <b><font color="red">Data Type (<xsl:value-of select="@status"/>): </font></b>
      </td>
    </xsl:if>
     <td>
       <xsl:if test="@status!=''">
         <font color="red">
           <xsl:value-of select="local-name()"/>
           <xsl:call-template name="display-chk-pos-values"/>
           <xsl:call-template name="display-pos-values"/>
         </font>
       </xsl:if>
       <xsl:if test="not(@status!='')">
         <xsl:value-of select="local-name()"/>
         <xsl:call-template name="display-chk-pos-values"/>
         <xsl:call-template name="display-pos-values"/>
       </xsl:if>
     </td>
  </tr>
</xsl:template>
  
<xsl:template name="display-chk-pos-values">
  <xsl:choose>
  <xsl:when test="CHK_POS_VAL='U'">
    ( Data is case-insensitive and stored as uppercase in database. )<br/>
  </xsl:when>
  <xsl:when test="CHK_POS_VAL='L'">
    ( Data is case-insensitive and stored as lowercase in database. )<br/>
  </xsl:when>
  <xsl:when test="CHK_POS_VAL='Y'">
    ( Data is case-sensitive and stored as it is in database. )<br/>
  </xsl:when>
  <xsl:otherwise>
    <br/>
  </xsl:otherwise>
  </xsl:choose>
</xsl:template>
  
<xsl:template name="display-pos-values">  
  <xsl:if test="VALUE!=''">
    <b>Possible Value : </b>
      <xsl:for-each select="VALUE">
        <xsl:if test="position()!=1"> <xsl:text>, </xsl:text> </xsl:if>
        <xsl:value-of select="current()"/>
		<xsl:if test="@enum_value!=''">
          (<xsl:value-of select="@enum_value"/>)
        </xsl:if>        
      </xsl:for-each>
      <br/>
  </xsl:if>
</xsl:template>

<xsl:template match="INTEGER">
  <xsl:choose>
  <xsl:when test="not(CHK_POS_VAL!='') or CHK_POS_VAL='N'">
    <xsl:if test="FROM_VALUE!=''">
      <xsl:variable name="text">
        INTEGER ( <xsl:value-of select="FROM_VALUE"/> - <xsl:value-of select="TO_VALUE"/> )
      </xsl:variable>
      <xsl:call-template name="display-column-attr">
        <xsl:with-param name="item" select="'Data Type'"/>
        <xsl:with-param name="text" select="$text"/>
    </xsl:call-template>
    </xsl:if>
    <xsl:if test="not(FROM_VALUE!='')">
      <xsl:call-template name="display-column-attr">
        <xsl:with-param name="item" select="'Data Type'"/>
        <xsl:with-param name="text" select="'INTEGER'"/>
    </xsl:call-template>
    </xsl:if>
  </xsl:when>
  <xsl:otherwise>
    <tr>
      <xsl:if test="not(@status!='')">
        <td width="150"><b>Data Type: </b></td>
      </xsl:if>
      <xsl:if test="@status!=''">
        <td width="150">
          <b><font color="red">Data Type (<xsl:value-of select="@status"/>): </font></b>
        </td>
      </xsl:if>
      <td>
        <xsl:if test="@status!=''">
          <font color="red">
            INTEGER<br/>
            <xsl:call-template name="display-pos-values"/>
          </font>
        </xsl:if>
        <xsl:if test="not(@status!='')">
          INTEGER<br/>
          <xsl:call-template name="display-pos-values"/>
        </xsl:if>
      </td>
    </tr>
  </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="DIGITS">
  <xsl:if test="FROM_VALUE!=''">
    <xsl:variable name="text">
      DIGITS ( <xsl:value-of select="FROM_VALUE"/> - <xsl:value-of select="TO_VALUE"/> )
    </xsl:variable>
    <xsl:call-template name="display-column-attr">
      <xsl:with-param name="item" select="'Data Type'"/>
      <xsl:with-param name="text" select="$text"/>
  </xsl:call-template>
  </xsl:if>
  <xsl:if test="not(FROM_VALUE!='')">
    <xsl:call-template name="display-column-attr">
      <xsl:with-param name="item" select="'Data Type'"/>
      <xsl:with-param name="text" select="'DIGITS'"/>
  </xsl:call-template>
  </xsl:if>
</xsl:template>

<xsl:template match="BOOLEAN">
  <xsl:call-template name="display-column-attr">
    <xsl:with-param name="item" select="'Data Type'"/>
    <xsl:with-param name="text" select="'BOOLEAN ( Y/N )'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="DEFAULT_VALUE">
  <xsl:if test="current()!=''">
    <tr>
      <xsl:if test="not(@status!='')">
        <td width="150"><b>Default Value: </b></td>
      </xsl:if>
      <xsl:if test="@status!=''">
        <td width="150">
          <b><font color="red">Default Value (<xsl:value-of select="@status"/>): </font></b>
        </td>
      </xsl:if>
      <td>
        <xsl:if test="@status!=''">
          <font color="red">
            <xsl:value-of select="current()"/>
            <xsl:if test="@enum_value!=''">
              (<xsl:value-of select="@enum_value"/>)
            </xsl:if>
          </font>
        </xsl:if>
        <xsl:if test="not(@status!='')">
          <xsl:value-of select="current()"/>
          <xsl:if test="@enum_value!=''">
            (<xsl:value-of select="@enum_value"/>)
          </xsl:if>
        </xsl:if>
      </td>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template match="FOREIGN_KEY">
  <xsl:if test="TABLENAME!=''">
    <xsl:variable name="text">
      <xsl:value-of select="TABLENAME"/> ( <xsl:value-of select="TOKENNAME"/> )
    </xsl:variable>
    <xsl:call-template name="display-column-attr">
      <xsl:with-param name="item" select="'Foreign Key'"/>
      <xsl:with-param name="text" select="$text"/>
  </xsl:call-template>
  </xsl:if>
</xsl:template>

<xsl:template name="display-column-attr">
  <xsl:param name="item"/>
  <xsl:param name="status"/>
  <xsl:param name="text"/>
  <xsl:if test="current()!='' or $text!=''">
    <tr>
      <xsl:choose>
      <xsl:when test="$status!='' or @status!=''">
        <td width="150"><font color="red"><b>
          <xsl:choose>
          <xsl:when test="@status!=''">
            <xsl:value-of select="$item"/> (<xsl:value-of select="@status"/>):
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="$item"/> (<xsl:value-of select="$status"/>):
          </xsl:otherwise>
          </xsl:choose>
        </b></font></td>
        <td><font color="red">
          <xsl:if test="$text!=''">
            <xsl:call-template name="display-column-attr-content">
              <xsl:with-param name="text" select="$text"/>
            </xsl:call-template>
          </xsl:if>
          <xsl:if test="not($text!='')">
            <xsl:call-template name="display-column-attr-content">
              <xsl:with-param name="text" select="current()"/>
            </xsl:call-template>
          </xsl:if>
        </font></td>
      </xsl:when>
      <xsl:otherwise>
        <td width="150"><b><xsl:value-of select="$item"/>:</b></td>
        <td>
          <xsl:if test="$text!=''">
            <xsl:call-template name="display-column-attr-content">
              <xsl:with-param name="text" select="$text"/>
            </xsl:call-template>
          </xsl:if>
          <xsl:if test="not($text!='')">
            <xsl:call-template name="display-column-attr-content">
              <xsl:with-param name="text" select="current()"/>
            </xsl:call-template>
          </xsl:if>
        </td>
      </xsl:otherwise>
      </xsl:choose>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="display-column-attr-content">
  <xsl:param name="text"/>
  <xsl:call-template name="replace-string">
    <xsl:with-param name="text" select="$text"/>
    <xsl:with-param name="replace" select="','"/>
    <xsl:with-param name="with" select="', '"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="replace-string">
  <xsl:param name="text"/>
  <xsl:param name="replace"/>
  <xsl:param name="with"/>
  <xsl:choose>
    <xsl:when test="contains($text,$replace)">
      <xsl:value-of select="substring-before($text,$replace)"/>
      <xsl:value-of select="$with"/>
      <xsl:call-template name="replace-string">
        <xsl:with-param name="text" select="substring-after($text,$replace)"/>
        <xsl:with-param name="replace" select="$replace"/>
        <xsl:with-param name="with" select="$with"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="$text"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="break">
  <xsl:param name="text"/>
   <xsl:choose>
   <xsl:when test="contains($text, '&#xa;')">
      <xsl:variable name="lineStr" select="substring-before($text,'&#xa;')"/>
      <xsl:value-of select="$lineStr"/>
      <xsl:if test="$lineStr!=''"><br/></xsl:if>
      <xsl:call-template name="break">
          <xsl:with-param name="text" select="substring-after($text,'&#xa;')"/>
      </xsl:call-template>
   </xsl:when>
   <xsl:otherwise>
        <xsl:value-of select="$text"/>
   </xsl:otherwise>
   </xsl:choose>
</xsl:template>

</xsl:stylesheet>

