<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:import href="BTS-Feature.xsl"/>

<xsl:template match="/">
  <xsl:apply-templates select="FEATURE_MATRIX"/>
</xsl:template>

<xsl:template match="FEATURE_MATRIX">
  <xsl:choose>
  <xsl:when test="$component='all'">
  	<xsl:call-template name="feature"/>
    <xsl:call-template name="sle"/>
    <xsl:call-template name="subscriber-tod-schedule"/>
    <xsl:call-template name="subscriber-sip-trigger-profile"/>
    <xsl:call-template name="feature-profile"/>
    <xsl:call-template name="subscriber-feature-data"/>
    <xsl:call-template name="feature-config"/>
  </xsl:when>
  <xsl:when test="$component='delta'">
    <xsl:if test="FEATURE[@status!='']">
      <xsl:call-template name="feature"/>
    </xsl:if>
    <xsl:if test="FEATURE[@status!='']/APPLIES_TO/TABLE[text()='SLE']">
      <xsl:call-template name="sle"/>
    </xsl:if>    
    <xsl:if test="FEATURE[@status!='']/APPLIES_TO/TABLE[text()='SUBSCRIBER_TOD_SCHEDULE']">
      <xsl:call-template name="subscriber-tod-schedule"/>
    </xsl:if>
    <xsl:if test="FEATURE[@status!='']/APPLIES_TO/TABLE[text()='SUBSCRIBER_SIP_TRIGGER_PROFILE']">
      <xsl:call-template name="subscriber-sip-trigger-profile"/>
    </xsl:if>       
    <xsl:if test="FEATURE[@status!='']/FEATURE_PROFILE">
      <xsl:call-template name="feature-profile"/>
    </xsl:if>    
    <xsl:if test="FEATURE[@status!='']/SUBSCRIBER_FEATURE_DATA">
      <xsl:call-template name="subscriber-feature-data"/>
    </xsl:if>
    <xsl:if test="FEATURE[@status!='']/FEATURE_CONFIG">
      <xsl:call-template name="feature-config"/>
    </xsl:if>        
  </xsl:when>
  <xsl:otherwise>
  	<xsl:if test="$component='FEATURE'">
      <xsl:call-template name="feature"/>
    </xsl:if>
  	<xsl:if test="$component='SLE'">
      <xsl:call-template name="sle"/>
    </xsl:if>    
  	<xsl:if test="$component='SUBSCRIBER_TOD_SCHEDULE'">
      <xsl:call-template name="subscriber-tod-schedule"/>
    </xsl:if>
  	<xsl:if test="$component='SUBSCRIBER_SIP_TRIGGER_PROFILE'">
      <xsl:call-template name="subscriber-sip-trigger-profile"/>
    </xsl:if>     
  	<xsl:if test="$component='FEATURE_PROFILE'">
      <xsl:call-template name="feature-profile"/>
    </xsl:if>    
  	<xsl:if test="$component='SUBSCRIBER_FEATURE_DATA'">
      <xsl:call-template name="subscriber-feature-data"/>
    </xsl:if>
  	<xsl:if test="$component='FEATURE_CONFIG'">
      <xsl:call-template name="feature-config"/>
    </xsl:if>        
  </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="feature">
  <xsl:if test="FEATURE!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <dl>
      <li><b>Feature:</b></li>
      <br/>
      <table border="5" width="95%" style="font-size:8pt" bordercolor="#8080cc" 
             bordercolorlight="#8080c0" bordercolordark="#400080" bgcolor="#ffffcc">
        <thead bgColor='lightgreen'>
          <th width="20%"><b>Feature Name</b></th>
          <th><b>Description</b></th>
        </thead>
        <xsl:apply-templates select="FEATURE">
    	  <xsl:sort select="@name"/>
        </xsl:apply-templates>
      </table>
    </dl>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template name="sle">
  <xsl:if test="FEATURE/APPLIES_TO/TABLE[text()='SLE']!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <dl>
      <li><b>Screening List Editing:</b></li>
      <br/>
      <table border="5" width="95%" style="font-size:8pt" bordercolor="#8080cc" 
             bordercolorlight="#8080c0" bordercolordark="#400080" bgcolor="#ffffcc">
        <thead bgColor='lightgreen'>
          <th width="10%"><b>Feature Name</b></th>
          <th><b>Description</b></th>
        </thead>
        <xsl:apply-templates select="FEATURE/APPLIES_TO/TABLE[text()='SLE']">
    	  <xsl:sort select="../../@name"/>
        </xsl:apply-templates>
      </table>
    </dl>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template name="subscriber-tod-schedule">
  <xsl:if test="FEATURE/APPLIES_TO/TABLE[text()='SLE']!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <dl>
      <li><b>Subscriber TOD Schedule:</b></li>
      <br/>
      <table border="5" width="95%" style="font-size:8pt" bordercolor="#8080cc" 
             bordercolorlight="#8080c0" bordercolordark="#400080" bgcolor="#ffffcc">
        <thead bgColor='lightgreen'>
          <th width="10%"><b>Feature Name</b></th>
          <th><b>Description</b></th>
        </thead>
        <xsl:apply-templates select="FEATURE/APPLIES_TO/TABLE[text()='SUBSCRIBER_TOD_SCHEDULE']">
    	  <xsl:sort select="../../@name"/>
        </xsl:apply-templates>
      </table>
    </dl>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template name="subscriber-sip-trigger-profile">
  <xsl:if test="FEATURE/APPLIES_TO/TABLE[text()='SLE']!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <dl>
      <li><b>Subscriber SIP Trigger Profile:</b></li>
      <br/>
      <table border="5" width="95%" style="font-size:8pt" bordercolor="#8080cc" 
             bordercolorlight="#8080c0" bordercolordark="#400080" bgcolor="#ffffcc">
        <thead bgColor='lightgreen'>
          <th width="10%"><b>Feature Name</b></th>
          <th><b>Description</b></th>
        </thead>
        <xsl:apply-templates select="FEATURE/APPLIES_TO/TABLE[text()='SUBSCRIBER_SIP_TRIGGER_PROFILE']">
    	  <xsl:sort select="../../@name"/>
        </xsl:apply-templates>
      </table>
    </dl>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template name="feature-profile">
  <xsl:if test="FEATURE/FEATURE_PROFILE!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <dl>
      <li><b>Feature Profile:</b></li>
      <br/>
      <table border="5" width="95%" style="font-size:8pt" bordercolor="#8080cc" 
             bordercolorlight="#8080c0" bordercolordark="#400080" bgcolor="#ffffcc">
        <thead bgColor='lightgreen'>
          <th width="10%"><b>Feature Name</b></th>
          <th width="25%"><b>Type</b></th>
          <th><b>Description</b></th>
        </thead>
        <xsl:apply-templates select="FEATURE/FEATURE_PROFILE">
    	  <xsl:sort select="../@name"/>
        </xsl:apply-templates>
      </table>
    </dl>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template name="subscriber-feature-data">
  <xsl:if test="FEATURE/SUBSCRIBER_FEATURE_DATA!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <dl>
      <li><b>Subscriber Feature Data:</b></li>
      <br/>
      <table border="5" width="95%" style="font-size:8pt" bordercolor="#8080cc" 
             bordercolorlight="#8080c0" bordercolordark="#400080" bgcolor="#ffffcc">
        <thead bgColor='lightgreen'>
          <th width="10%"><b>Feature Name</b></th>
          <th width="25%"><b>Type</b></th>
          <th><b>Description</b></th>
        </thead>
        <xsl:apply-templates select="FEATURE/SUBSCRIBER_FEATURE_DATA">
    	  <xsl:sort select="../@name"/>
        </xsl:apply-templates>
      </table>
    </dl>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template name="feature-config">
  <xsl:if test="FEATURE/FEATURE_CONFIG!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <dl>
      <li><b>Feature Config:</b></li>
      <br/>
      <table border="5" width="95%" style="font-size:8pt" bordercolor="#8080cc" 
             bordercolorlight="#8080c0" bordercolordark="#400080" bgcolor="#ffffcc">
        <thead bgColor='lightgreen'>
          <th width="10%"><b>Feature Name</b></th>
          <th width="25%"><b>Type</b></th>
          <th><b>Description</b></th>
        </thead>
        <xsl:apply-templates select="FEATURE/FEATURE_CONFIG">
    	  <xsl:sort select="../@name"/>
        </xsl:apply-templates>
      </table>
    </dl>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template match="FEATURE">
  <xsl:variable name="doc" select="document($mDescFile)/FEATURE_MATRIX/FEATURE[@name=current()/@name]"/>
  <tr bgColor='lightyellow'>
    <td>
      <xsl:if test="not(@status!='')">	
		<xsl:value-of select="@name"/>
      </xsl:if>
      <xsl:if test="@status!=''">   
        <font color='red'><xsl:value-of select="@name"/></font>
      </xsl:if>
    </td>  
    <td>
      <table border="0" width="100%" style="font-size:8pt">
        <xsl:call-template name="status"/>
        <xsl:call-template name="description">
          <xsl:with-param name="doc" select="$doc"/>
        </xsl:call-template>
        <xsl:call-template name="associate-feature">
          <xsl:with-param name="doc" select="$doc"/>
        </xsl:call-template>
        <xsl:call-template name="service-type">
          <xsl:with-param name="doc" select="$doc"/>
        </xsl:call-template>
        <xsl:call-template name="termination-type">
          <xsl:with-param name="doc" select="$doc"/>
        </xsl:call-template>                
      </table>
    </td>
  </tr>
</xsl:template>

<xsl:template match="TABLE">
  <xsl:variable name="doc" select="document($mDescFile)/FEATURE_MATRIX/FEATURE[@name=current()/../../@name]"/>
  <tr bgColor='lightyellow'>
    <td>
      <xsl:if test="not(@status!='')">	
		<xsl:value-of select="../../@name"/>
      </xsl:if>
      <xsl:if test="@status!=''">   
        <font color='red'><xsl:value-of select="../../@name"/></font>
      </xsl:if>
    </td>  
    <td>
      <table border="0" width="100%" style="font-size:8pt">
        <xsl:call-template name="status"/>
        <xsl:call-template name="description">
          <xsl:with-param name="doc" select="$doc"/>
        </xsl:call-template>
        <xsl:call-template name="associate-feature">
          <xsl:with-param name="doc" select="$doc"/>
        </xsl:call-template>
        <xsl:call-template name="service-type">
          <xsl:with-param name="doc" select="$doc"/>
        </xsl:call-template>
        <xsl:call-template name="termination-type">
          <xsl:with-param name="doc" select="$doc"/>
        </xsl:call-template>                
      </table>
    </td>
  </tr>
</xsl:template>

<xsl:template match="FEATURE_CONFIG|FEATURE_PROFILE|SUBSCRIBER_FEATURE_DATA">
  <xsl:variable name="fp" select="document($mDescFile)/FEATURE_MATRIX/FEATURE[@name=current()/../@name]/FEATURE_PROFILE"/>
  <xsl:variable name="sfd" select="document($mDescFile)/FEATURE_MATRIX/FEATURE[@name=current()/../@name]/SUBSCRIBER_FEATURE_DATA"/>
  <xsl:variable name="fc" select="document($mDescFile)/FEATURE_MATRIX/FEATURE[@name=current()/../@name]/FEATURE_CONFIG"/>
  <xsl:variable name="ftype" select="local-name()"/>
  <xsl:for-each select="TYPE">
    <xsl:sort select="@name"/>
    <xsl:choose>
    <xsl:when test="$ftype='SUBSCRIBER_FEATURE_DATA'">
      <xsl:call-template name="feature-type">
        <xsl:with-param name="doc" select="$sfd/TYPE[@name=current()/@name]"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:when test="$ftype='FEATURE_CONFIG'">
      <xsl:call-template name="feature-type">
        <xsl:with-param name="doc" select="$fc/TYPE[@name=current()/@name]"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:call-template name="feature-type">
        <xsl:with-param name="doc" select="$fp/TYPE[@name=current()/@name]"/>
      </xsl:call-template>
    </xsl:otherwise>
    </xsl:choose>
  </xsl:for-each>
</xsl:template>

<xsl:template name="feature-type">
  <xsl:param name="doc"/>
  <tr bgColor='lightyellow'>
    <td>
      <xsl:if test="not(@status!='')">	
		<xsl:value-of select="../../@name"/>
      </xsl:if>
      <xsl:if test="@status!=''">   
        <font color='red'><xsl:value-of select="../../@name"/></font>
      </xsl:if>
    </td>  
    <td>
      <xsl:if test="not(@status!='')">	
		<xsl:value-of select="@name"/>
      </xsl:if>
      <xsl:if test="@status!=''">   
        <font color='red'><xsl:value-of select="@name"/></font>
      </xsl:if>
    </td>
    <td>
      <table border="0" width="100%" style="font-size:8pt">
        <xsl:call-template name="status"/>
        <xsl:call-template name="description">
          <xsl:with-param name="doc" select="$doc"/>
        </xsl:call-template>
        <xsl:apply-templates select="STRING|INTEGER|DIGITS|BOOLEAN"/>
        <xsl:apply-templates select="DEFAULT_VALUE"/>
        <xsl:apply-templates select="FOREIGN_KEY"/>
      </table>
    </td>
  </tr>
</xsl:template>

<xsl:template name="associate-feature">
  <xsl:param name="doc"/>
  <xsl:variable name="desc" select="$doc/ASSOCIATE_FEATURE"/>
  <xsl:if test="$desc!=''">
    <tr>
      <td width="150"><b>Associate Feature: </b></td>
      <td>
        <xsl:for-each select="$desc/FEATURE_NAME">
    	  <xsl:if test="position()!=1"> <xsl:text>, </xsl:text> </xsl:if>
    	  <xsl:value-of select="current()"/>
  		</xsl:for-each>
      </td>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="service-type">
  <xsl:param name="doc"/>
  <xsl:variable name="desc" select="$doc/SERVICE_TYPE"/>
  <xsl:if test="$desc!=''">
    <tr>
      <td width="150"><b>Service Type: </b></td>
      <td><xsl:apply-templates select="$desc"/></td>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="termination-type">
  <xsl:param name="doc"/>
  <xsl:variable name="desc" select="$doc/TERMINATION_TYPE"/>
  <xsl:if test="$desc!=''">
    <tr>
      <td width="150"><b>Termination Type: </b></td>
      <td><xsl:apply-templates select="$desc"/></td>
    </tr>
  </xsl:if>
</xsl:template>

</xsl:stylesheet>

